/**
* Copyright Zendesk, Inc.
*
* Use of this source code is governed under the Apache License, Version 2.0
* found at http://www.apache.org/licenses/LICENSE-2.0.
*/
import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import { HUE, INHERIT_SIZE } from '../types/index.js';
import '../styled/StyledBlockquote.js';
import { StyledCode } from '../styled/StyledCode.js';
import '../styled/StyledCodeBlock.js';
import '../styled/StyledCodeBlockContainer.js';
import '../styled/StyledCodeBlockLine.js';
import '../styled/StyledCodeBlockToken.js';
import '../styled/StyledEllipsis.js';
import '../styled/StyledFont.js';
import '../styled/StyledIcon.js';
import '../styled/StyledList.js';
import '../styled/StyledListItem.js';
import '../styled/StyledParagraph.js';

const Code = forwardRef((_ref, ref) => {
  let {
    hue,
    size,
    ...other
  } = _ref;
  return React.createElement(StyledCode, Object.assign({
    ref: ref,
    $hue: hue,
    $size: size
  }, other));
});
Code.displayName = 'Code';
Code.propTypes = {
  hue: PropTypes.oneOf(HUE),
  size: PropTypes.oneOf(INHERIT_SIZE)
};
Code.defaultProps = {
  hue: 'grey',
  size: 'inherit'
};

export { Code };
